# RedUI fields

Red UI fields provides you some templates for mobile applications.

---

## Installation
You can start using it by following the steps below:
 - Install [red-ui core](http://code.zeedhi.com/redui-components/red-ui).
 - Add on your project bower.json file this dependency
    - Example:

```JSON
    "dependencies": {
        "red-ui-fields": "*"
    }
```     

 - Run `bower install`
 - Add the path to rui's fields JavaScript and css on your GruntFile.json.
    - Example:
    
```JavaScript
    var srcFiles = {
		libsJS: [
            "bower_components/red-ui-fields/dist/rui-fields.js"
        ],
        libsCSS: [
        	"bower_components/red-ui-fields/dist/rui-fields.css"
        ]
	};
```

 - Add the path to rui's fields css and less at the less routine on your GruntFile.json.
    - Example:
    
```JavaScript
		less: {
			development: {
				files: {
					'bower_components/red-ui-fields/dist/rui-fields.css': "bower_components/red-ui-fields/src/assets/css/**/*.less"
				}
			}
		}
```

 -  Run `grunt`

---

## Templates
To use one of these templates just put the path to it's html in your template properity;
 - Example
    
```JSON
    "template": "rui-fields#field/date.html"
```

### Button
A button template that triggers a event by clicking on it.
Properties:
 - class: defines the button's size relative to the screen's size.
 - flatButton: defines if the button is flat.
 - label: defines the text to be displayed on the field.
 - name: defines the name of the field to the application.
 - readOnly: defines if the field is read only.
    - Example:

```JSON
    {
    	"name": "btn_comum",
    	"label": "Raised Button",
    	"class": "12",
    	"isVisible": true,
    	"flatButton": false,
    	"readOnly": false,
    	"template": "rui-fields#field/button.html"
    },
    {
    	"name": "btn_comum",
    	"label": "Flat Button",
    	"class": "12",
    	"isVisible": true,
    	"flatButton": true,
    	"readOnly": false,
    	"template": "rui-fields#field/button.html"
    }
```

### Date
A date template that displayes the selected date, by clicking on the field a calendar is opened so you can change the selected date.
Properties:
 - defaultValue: defines a default date.
 - hideOverlay: hides the overlay.
 - label: defines the text to be displayed on the field.
 - name: defines the name of the field to the application.
 - readOnly: defines if the field is read only.
    - Example:

```JSON
    {
    	"name": "DTENTREGA",
    	"label": "Date",
    	"template": "rui-fields#field/date.html",
    	"defaultValue": "30/12/2017",
    	"hideOverlay": false,
    	"isVisible": true,
    	"readOnly": false
    }
```


### Text Area
Text area is a multi-line text input control.

- label: the text to be displayed above the field.
- maxlength: defines the maxime number of characters that can be written on this field.
- name: defines the name of the field to the application.
- placeholder: specifies a short hint that describes the expected value of the text area. This text is displayed when no text has been written).
- readOnly: defines if the field is read only.
- template: defines the path to the template.
- textRows: the number of rows that will be filled by the text area. If text takes more than this number it will aumatically scrool. 
    - Example:
    
```JSON
    {
		"name": "DESC",
		"label": "Description",
		"template": "rui-fields#field/text-area.html",
		"textRows": "3",
		"placeholder": "Describe your project",
		"maxlength": 255,
		"isVisible": true,
		"readOnly": false
	}
```


### Text
A field that allows the user to imput some data.

- label: the text to be displayed above the field.
- name: defines the name of the field to the application.
- maxlength: defines the maxime number of characters that can be written on this field.
- placeholder: specifies a short hint that describes the expected value of the text area. This text is displayed when no text has been written).
- readOnly: defines if the field is read only.
- template: defines the path to the template.
- type: defines the type of the imput field. The types are the same types allowed by html5.
    - Example:
    
```JSON
    {
		"name": "MAIL",
		"label": "EMAIL",
		"maxlength": 100,
		"template": "rui-fields#field/text.html",
		"type": "email"
		"textRows": "1",
		"placeholder": "example@test.com"
		"isVisible": true,
		"readOnly": false
	}
```


### Time
A time template that displayes the selected time, by clicking on the field a clock is opened so you can change the selected time.
Properties:
 - defaultValue: defines a default time.
 - hideOverlay: hides the overlay.
 - label: defines the text to be displayed on the field.
 - name: defines the name of the field to the application.
 - readOnly: defines if the field is read only.
    - Example:
    
```JSON
    {
		"name": "HOUR",
		"label": "Time",
		"template": "rui-fields#field/time.html",
		"defaultValue": "00:00",
		"isVisible": true,
		"hideOverlay": false,
		"readOnly": false
	}
```

---

```
Made by:
- Bernardo Santos bernardo.santos@teknisa.com
- Gabriel Andrade gabriel.andrade@teknisa.com
- Gabriel Mello gabriel.mello@teknisa.com
- Luiz Filho luiz.filho@teknisa.com
- Matheus Resende matheus.guedes@teknisa.com
- Samuel Cunha samuel.cunha@teknisa.com
- Rodrigo Rodrigues rodrigo.rodrigues@teknisa.com