function LibLoginService(restEngine, requestDataSourceEngine){
    var buildRequestObj = function(baseUrl, service, params) {
        return {
            service: service,
            params: params,
            typeRequest: "post",
            baseUrl: baseUrl
        };
    };

    this.requestToken = function(clientId, loginURL, bHash) {
        var requestObj = buildRequestObj(loginURL, "/lm_requestToken", { "CLIENT_ID": clientId, "BHASH":  bHash });
        return restEngine.post(requestObj).then(function(data){
            return data && data.dataset ? data.dataset.token : [];
        });
    };

    this.startSession = function(token, versionFile, productId) {
        var filter = [ {
            name: 'TOKEN',
            value: token,
            operator: '='
        }, {
            name: 'VERSION_FILE',
            value: versionFile,
            operator: '='
        }, {
            name: 'PRODUCT_ID',
            value: productId,
            operator: '='
        }, {
            name: 'IS_LOGGED',
            value: localStorage.getItem('IS_LOGGED') || false,
            operator: '='
        } ];

        return requestDataSourceEngine.getDataSource('lib#/lib_startSession', filter).then(function(data){
            if(typeof data == 'string') {
                return {
                    isError : true,
                    message : data
                };
            }
            return data && data.dataset ? data.dataset.system : false;
        });
    };

    this.validateUser = function(cdOperator, password) {
        var filter = [ {
            name: 'USER',
            value: cdOperator,
            operator: '='
        }, {
            name: 'PASSWORD',
            value: password,
            operator: '='
        } ];

        return requestDataSourceEngine.getDataSource('lib#/lib_validateUser', filter);
    };

    this.getUriParams = function(title, theme, splashFavicon, image, product, settings, language, productId, service, ip, bHash) {
        if(service === undefined) {
            service = true;
        }

        var params = [];

        if(title)         params.push({desc: 'title',         value: title});
        if(theme)         params.push({desc: 'theme',         value: theme});
        if(image)         params.push({desc: 'image' ,        value: image});
        if(product)       params.push({desc: 'product',       value: product});
        if(settings)      params.push({desc: 'settings',      value: settings});
        if(language)      params.push({desc: 'language',      value: language});
        if(splashFavicon) params.push({desc: 'splashFavicon', value: splashFavicon});
        if(productId)     params.push({desc: 'productId',     value: productId});
                          params.push({desc: 'service',       value: service});
        if(ip)            params.push({desc: 'ip',            value: ip});
        if(bHash)         params.push({desc: 'bHash',         value: bHash});

        return params;
    };

    this.logout = function(){
        return requestDataSourceEngine.getDataSource('lib#/lib_logout', []);
    };

    this.getIpAddress = function(){
        return requestDataSourceEngine.getDataSource('lib#/lib_getIpAddress', []);
    };

    this.getModulesVersion = function(){
        return requestDataSourceEngine.getDataSource('lib#/lib_getModulesVersion', []);
    };

    this.generateModulesVersionFile = function() {
        return requestDataSourceEngine.setDataSource('lib#/lib_generateModulesVersionFile', [ { changed: true } ]);
    };

    this.downloadModulesVersionFile = function(fileName) {
        var serviceUrl = window.serviceUrl;
        window.open(serviceUrl + "/lib_downloadModulesVersionFile?requestType=DataSet&dataset[0][FILE_NAME]=" + fileName);
    };
}

Configuration(function(ContextRegister){
    ContextRegister.register('LibLoginService', LibLoginService);
});

